@@ -89,7 +89,6 @@ export const TaskTrySelect = ({ onSelectTryNumber, selectedTryNumber, taskInstan
         <Select.Root
           collection={tryOptions}
           data-testid="select-task-try"
-          defaultValue={[selectedTryNumber?.toString() ?? finalTryNumber.toString()]}
           onValueChange={(details) => {
             if (onSelectTryNumber) {
               onSelectTryNumber(
@@ -97,6 +96,7 @@ export const TaskTrySelect = ({ onSelectTryNumber, selectedTryNumber, taskInstan
               );
             }
           }}
+          value={[selectedTryNumber?.toString() ?? finalTryNumber.toString()]}
           width="200px"
         >
           <Select.Trigger>
