@@ -33,3 +33,7 @@ export * from "./Toaster";
 export * from "./Breadcrumb";
 export * from "./Clipboard";
 export * from "./Popover";
+export * from "./Checkbox";
+export * from "./ResetButton";
+export * from "./InputWithAddon";
+export * from "./ButtonGroupToggle";
