@@ -17,37 +17,40 @@
  * under the License.
  */
 import { Flex, Box } from "@chakra-ui/react";
+import { useCallback } from "react";
 import { useParams, useSearchParams } from "react-router-dom";
 
 import type { GridRunsResponse } from "openapi/requests";
 import { RunTypeIcon } from "src/components/RunTypeIcon";
-import { useGridTiSummaries } from "src/queries/useGridTISummaries.ts";
+import { useHover } from "src/context/hover";
 
 import { GridButton } from "./GridButton";
-import { TaskInstancesColumn } from "./TaskInstancesColumn";
-import type { GridTask } from "./utils";
 
 const BAR_HEIGHT = 100;
 
 type Props = {
   readonly max: number;
-  readonly nodes: Array<GridTask>;
+  readonly onClick?: () => void;
   readonly run: GridRunsResponse;
 };
 
-export const Bar = ({ max, nodes, run }: Props) => {
+export const Bar = ({ max, onClick, run }: Props) => {
   const { dagId = "", runId } = useParams();
   const [searchParams] = useSearchParams();
+  const { hoveredRunId, setHoveredRunId } = useHover();
 
   const isSelected = runId === run.run_id;
-
+  const isHovered = hoveredRunId === run.run_id;
   const search = searchParams.toString();
-  const { data: gridTISummaries } = useGridTiSummaries(run);
+
+  const handleMouseEnter = useCallback(() => setHoveredRunId(run.run_id), [setHoveredRunId, run.run_id]);
+  const handleMouseLeave = useCallback(() => setHoveredRunId(undefined), [setHoveredRunId]);
 
   return (
     <Box
-      _hover={{ bg: "blue.subtle" }}
-      bg={isSelected ? "blue.muted" : undefined}
+      bg={isSelected ? "brand.emphasized" : isHovered ? "brand.muted" : undefined}
+      onMouseEnter={handleMouseEnter}
+      onMouseLeave={handleMouseLeave}
       position="relative"
       transition="background-color 0.2s"
     >
@@ -55,6 +58,7 @@ export const Bar = ({ max, nodes, run }: Props) => {
         alignItems="flex-end"
         height={BAR_HEIGHT}
         justifyContent="center"
+        onClick={onClick}
         pb="2px"
         px="5px"
         width="18px"
@@ -62,10 +66,10 @@ export const Bar = ({ max, nodes, run }: Props) => {
       >
         <GridButton
           alignItems="center"
-          color="white"
+          color="fg"
           dagId={dagId}
           flexDir="column"
-          height={`${((run.duration ?? 0) / max) * BAR_HEIGHT}px`}
+          height={`${(run.duration / max) * BAR_HEIGHT}px`}
           justifyContent="flex-end"
           label={run.run_after}
           minHeight="14px"
@@ -74,14 +78,9 @@ export const Bar = ({ max, nodes, run }: Props) => {
           state={run.state}
           zIndex={1}
         >
-          {run.run_type !== "scheduled" && <RunTypeIcon runType={run.run_type} size="10px" />}
+          {run.run_type !== "scheduled" && <RunTypeIcon color="white" runType={run.run_type} size="10px" />}
         </GridButton>
       </Flex>
-      <TaskInstancesColumn
-        nodes={nodes}
-        runId={run.run_id}
-        taskInstances={gridTISummaries?.task_instances ?? []}
-      />
     </Box>
   );
 };
