@@ -18,10 +18,12 @@
  */
 import { Box, Separator, Heading, HStack, Stack } from "@chakra-ui/react";
 import type { TaskInstanceState, TaskInstanceStateCount } from "openapi-gen/requests/types.gen";
+import { useTranslation } from "react-i18next";
 import { MdOutlineTask } from "react-icons/md";
 import { Link as RouterLink } from "react-router-dom";
 
 import { StateBadge } from "src/components/StateBadge";
+import { SearchParamsKeys } from "src/constants/searchParams";
 
 import { MetricSection } from "./MetricSection";
 
@@ -53,36 +55,40 @@ export const TaskInstanceMetrics = ({
   startDate,
   taskInstanceStates,
   total,
-}: TaskInstanceMetricsProps) => (
-  <Box borderRadius={5} borderWidth={1} mt={2} p={4}>
-    <HStack>
-      <RouterLink
-        to={`/task_instances?start_date=${startDate}${endDate === undefined ? "" : `&end_date=${endDate}`}`}
-      >
-        <StateBadge colorPalette="blue" fontSize="md" variant="solid">
-          <MdOutlineTask />
-          {total}
-        </StateBadge>
-      </RouterLink>
-      <Heading size="md">Task Instances</Heading>
-    </HStack>
-    <Separator my={3} />
-    <Stack gap={4}>
-      {TASK_STATES.sort((stateA, stateB) =>
-        taskInstanceStates[stateA] > taskInstanceStates[stateB] ? -1 : 1,
-      ).map((state) =>
-        taskInstanceStates[state] > 0 ? (
-          <MetricSection
-            endDate={endDate}
-            key={state}
-            kind="task_instances"
-            runs={taskInstanceStates[state]}
-            startDate={startDate}
-            state={state as TaskInstanceState}
-            total={total}
-          />
-        ) : undefined,
-      )}
-    </Stack>
-  </Box>
-);
+}: TaskInstanceMetricsProps) => {
+  const { t: translate } = useTranslation();
+
+  return (
+    <Box borderRadius={5} borderWidth={1} mt={2} p={4}>
+      <HStack>
+        <RouterLink
+          to={`/task_instances?${SearchParamsKeys.START_DATE}=${startDate}${endDate === undefined ? "" : `&${SearchParamsKeys.END_DATE}=${endDate}`}`}
+        >
+          <StateBadge colorPalette="brand" fontSize="md" variant="solid">
+            <MdOutlineTask />
+            {total}
+          </StateBadge>
+        </RouterLink>
+        <Heading size="md">{translate("taskInstance", { count: total })}</Heading>
+      </HStack>
+      <Separator my={3} />
+      <Stack gap={4}>
+        {TASK_STATES.sort((stateA, stateB) =>
+          taskInstanceStates[stateA] > taskInstanceStates[stateB] ? -1 : 1,
+        ).map((state) =>
+          taskInstanceStates[state] > 0 ? (
+            <MetricSection
+              endDate={endDate}
+              key={state}
+              kind="task_instances"
+              runs={taskInstanceStates[state]}
+              startDate={startDate}
+              state={state as TaskInstanceState}
+              total={total}
+            />
+          ) : undefined,
+        )}
+      </Stack>
+    </Box>
+  );
+};
