@@ -257,6 +257,7 @@ export const TaskInstances = () => {
     },
     undefined,
     {
+      placeholderData: (prev) => prev,
       refetchInterval: (query) =>
         query.state.data?.task_instances.some((ti) => isStatePending(ti.state)) ? refetchInterval : false,
     },
@@ -285,7 +286,7 @@ export const TaskInstances = () => {
         errorMessage={<ErrorAlert error={error} />}
         initialState={tableURLState}
         isLoading={isLoading}
-        modelName={translate("common:taskInstance_other")}
+        modelName="common:taskInstance"
         onStateChange={setTableURLState}
         total={data?.total_entries}
       />
